==> haskell-fgl-arbitrary-0.2.0.6-130.1-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-Al9VU2ZFs7XFEVuFGWdHSl
key:                  fgl-arbitrary-0.2.0.6-Al9VU2ZFs7XFEVuFGWdHSl
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  883ad85ff693bfa3ba33ff688987a212
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-Al9VU2ZFs7XFEVuFGWdHSl
depends:
    QuickCheck-2.14.3-JVpLupMbhPgL6XTp3rPxED base-4.16.4.0
    fgl-5.8.2.0-9xKCfKf7Jnm7bBKKT2bzyG

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-fgl-arbitrary-0.2.0.6-132-riscv64.pkg.tar.zst: usr/share/haskell/register/haskell-fgl-arbitrary.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 fgl-arbitrary
version:              0.2.0.6
visibility:           public
id:                   fgl-arbitrary-0.2.0.6-KFDt6D2T7ThAJ3w6LoanGZ
key:                  fgl-arbitrary-0.2.0.6-KFDt6D2T7ThAJ3w6LoanGZ
license:              BSD-3-Clause
copyright:            Ivan Lazar Miljenovic
maintainer:           Ivan.Miljenovic@gmail.com
author:               Ivan Lazar Miljenovic
synopsis:             QuickCheck support for fgl
description:
    Provides Arbitrary instances for fgl graphs (to avoid adding a
    QuickCheck dependency for fgl whilst still making the instances
    available to others).

    Also available are non-fgl-specific functions for generating
    graph-like data structures.

category:             Testing, Graphs
abi:                  d1313ff4d79fff3138581d6d4cdfcc75
exposed:              True
exposed-modules:      Data.Graph.Inductive.Arbitrary
import-dirs:          /usr/lib/ghc-9.2.8/site-local/fgl-arbitrary-0.2.0.6
library-dirs:         /usr/lib/ghc-9.2.8/site-local/fgl-arbitrary-0.2.0.6
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-fgl-arbitrary
hs-libraries:         HSfgl-arbitrary-0.2.0.6-KFDt6D2T7ThAJ3w6LoanGZ
depends:
    QuickCheck-2.14.3-AB831W8sF74KL3cz7DxP1X base-4.16.4.0
    fgl-5.8.2.0-Eb6xdEigYbA8WAuh82pZJA

haddock-interfaces:
    /usr/share/doc/haskell-fgl-arbitrary/html/fgl-arbitrary.haddock

haddock-html:         /usr/share/doc/haskell-fgl-arbitrary/html
' | '/usr/bin/ghc-pkg-9.2.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
